@@ -1,4 +1,4 @@
-from typing import Any
+from typing import Any, Dict
 
 import pandas as pd
 from requests_toolbelt import sessions
@@ -31,7 +31,7 @@ class Client:
         *,  # keyword-only arguments
         dataset_id: int = None,
         dataset_title: str = None,
-    ) -> dict[str, Any]:
+    ) -> Dict[str, Any]:
         """
         Push data (in a pandas DataFrame) to the Flow API.
 
